@@ -7,7 +7,6 @@
 #' 
 #' @param host hostname.
 #' @param port host port.
-#' @param sleep number of seconds to wait to establish the connection.
 #' @param ... further arguments are passed on to [DSD_ReadStream()].
 #'
 #' @returns A [stream::DSD] object.
@@ -17,12 +16,10 @@
 #' port <- httpuv::randomPort()
 #' port
 #' 
-#' # create a background DSD process sending data to port 8001
+#' # create a background DSD process sending data to the port
 #' rp1 <- DSD_Gaussians(k = 3, d = 3) %>% publish_DSD_via_Socket(port = port)
 #' rp1
 #'
-#' Sys.sleep(2)  # wait for the socket to become available
-#'
 #' # create a DSD that connects to the socket. Note that we need to 
 #' # specify the column names of the stream
 #' dsd <- DSD_ReadSocket(port = port, col.names = c("x", "y", "z", ".class"))
@@ -39,8 +36,7 @@
 #' if (rp1$is_alive()) rp1$kill()
 #' rp1
 #' @export
-DSD_ReadSocket <- function(host = "localhost", port, sleep = 2, ...) {
-  con <- socketConnection(host, port, server = FALSE, open = 'r')
-  Sys.sleep(sleep)
-  DSD_ReadStream(con, ...)
+DSD_ReadSocket <- function(host = "localhost", port, ...) {
+  retry(con <- socketConnection(host, port, server = FALSE, open = 'r'))
+  retry(DSD_ReadStream(con, ...))
 }
